==> netscape-6.2.3-i686-1.tgz: content/aim/InviteAFriend3_5.js <==

 function picker(e)
	{
	var addBuddyButton = document.getElementById("btnaddbuddy");
    var imButton = document.getElementById("btnim");
	addBuddyButton.setAttribute("disabled","false")
    imButton.setAttribute("disabled","false");
	}

 function cmdAddBuddy()
  {
    var targetValue = getSelectedUser();
    if (targetValue) {
      openDialog("chrome://aim/content/BuddyAddBuddy.xul", "", "modal=yes,titlebar,chrome", 
                 null, null, targetValue);
    }
  }
  
  function cmdSendIM()
  {
    var targetValue = getSelectedUser();
    if (targetValue) {
      aimIMInvokeIMForm(targetValue, null);
    }
  }
  
  function getSelectedUser()
  {
    var tree = document.getElementById("emailsearchresultstree");
    if (tree.selectedItems.length > 0)
      return tree.selectedItems[0].firstChild.firstChild.getAttribute("label");
    else
      return null;
  }



function showScrNames(){
	if (parent.wizardManager) {
		var email = parent.queryEmailAddress;
		var numHits =parent.numHits;
		var containerArray = parent.containerArray;
	}
	else
	{
		screenlistObj=window.arguments[0];
		var email = screenlistObj.emailAddr;
		var numHits =screenlistObj.snNumber;
		var containerArray = screenlistObj.screenList;
	}
	document.getElementById("usersnum").setAttribute("value",numHits);
	document.getElementById("emailaddress").setAttribute("value", email);
	var searchResultsArray = containerArray;

	var searchResults = document.getElementById('theresults');
	
	


	for(k=0;k<searchResultsArray.length;k++){
	var item = document.createElement("treeitem");
                 var row = document.createElement("treerow");
                 var cell = document.createElement("treecell");
                 cell.setAttribute("label", searchResultsArray[k]);
                 cell.setAttribute("issearchresult","true");
                 row.appendChild(cell);
				 item.appendChild(row);
                 searchResults.appendChild(item);
		
	}
	
	searchResultsArray.length=0;

}

==> netscape-7.2-i686-1.tgz: content/aim/InviteAFriend3_5.js <==

 function picker(e)
	{
	var addBuddyButton = document.getElementById("btnaddbuddy");
    var imButton = document.getElementById("btnim");
	addBuddyButton.setAttribute("disabled","false")
    imButton.setAttribute("disabled","false");
	}

 function cmdAddBuddy()
  {
    var targetValue = getSelectedUser();
    if (targetValue) {
      openDialog("chrome://aim/content/BuddyAddBuddy.xul", "", "modal=yes,titlebar,chrome", 
                 null, null, targetValue);
    }
  }
  
  function cmdSendIM()
  {
    var targetValue = getSelectedUser();
    if (targetValue) {
      aimIMInvokeIMForm(targetValue);
    }
  }
  
  function getSelectedUser()
  {
    var listbox = document.getElementById("emailsearchresultslist");
    if (listbox.selectedItem)
      return listbox.selectedItem.getAttribute("label");
    else
      return null;
  }



function showScrNames(){
	if (parent.wizardManager) {
		var email = parent.queryEmailAddress;
		var numHits =parent.numHits;
		var containerArray = parent.containerArray;
	}
	else
	{
		screenlistObj=window.arguments[0];
		var email = screenlistObj.emailAddr;
		var numHits =screenlistObj.snNumber;
		var containerArray = screenlistObj.screenList;
	}
	document.getElementById("usersnum").setAttribute("value",numHits);
	document.getElementById("emailaddress").setAttribute("value", email);
	var searchResultsArray = containerArray;

	var searchResults = document.getElementById('emailsearchresultslist');

	for(k=0;k<searchResultsArray.length;k++){
	var item = document.createElement("listitem");
 item.setAttribute("label", searchResultsArray[k]);
 item.setAttribute("issearchresult","true");
  searchResults.appendChild(item);
		
	}
	
	searchResultsArray.length=0;

}
